import { Args, Query, Resolver } from '@nestjs/graphql';
import { FisAppQueryService } from './fisAppQuery.service';

import { Observable, of } from 'rxjs';
import { DataServiceArgument, DataServiceMessage } from './entities/DataService.entity';

import {  APAccountProfileUnion } from './entities/APAccountProfile';
import { AccountProfileArgument, AccountProfileUnion } from './entities/AccountProfile';

import { CMAccountProfileUnion } from './entities/CMAccountProfile';
import { ARAccountProfileUnion } from './entities/ARAccountProfile';
import { DocumentUnion, DocumentArgument } from './entities/Document';
import { ARInvoiceDocumentUnion } from './entities/ARInvoiceDocument';
import { APInvoiceDocumentUnion } from './entities/APInvoiceDocument';
import { OrganisationProfileArgument, OrganisationProfileUnion } from './entities/OrganisationProfile';
import { ServiceProgramProfileArgument, ServiceProgramProfileUnion} from './entities/ServiceProgramProfile';
import { FisServiceProgramProfileArgument, FisServiceProgramUnion } from './entities/FisServiceProgram';
import { RoleTypeProfileArgument, RoleTypeProfileUnion } from './entities/RoleTypeProfile';
import { APReceiptDocumentUnion } from './entities/APReceiptDocument';
import { ARReceiptDocumentUnion } from './entities/ARReceiptDocument';
import { ProductProfileArgument, ProductProfileUnion } from './entities/ProductProfile';
import { LeaveBalanceArgument, LeaveBalanceUnion } from './entities/LeaveBalance';
import { LeaveHistoryArgument, LeaveHistoryUnion } from './entities/LeaveHistory';
import { LeaveTypeProfileArgument, LeaveTypeProfileUnion } from './entities/LeaveTypeProfile';

@Resolver(() => DataServiceMessage)
export class FisAppQueryResolver {

  constructor(
    private readonly fisAppQueryService: FisAppQueryService
  ) { }



  @Query(() => DataServiceMessage, { name: 'dataservice' })
  getDataService(@Args() dataservice: DataServiceArgument): Observable<DataServiceMessage> {
    const { className, filter, returnFormatType } = dataservice;
    return this.fisAppQueryService.getData(className, filter, returnFormatType);
  }

  @Query(() => AccountProfileUnion, { name: 'AccountProfileQuery' })
  getAccountProfileDataService(@Args() dataservice: AccountProfileArgument): Observable<typeof AccountProfileUnion> {
    const { filter, returnFormatType } = dataservice;
    return this.fisAppQueryService.AccountProfileGetData(filter, returnFormatType);
  }

  @Query(() => APAccountProfileUnion, { name: 'APAccountProfileQuery' })
  getAPAccountProfileDataService(@Args() dataservice: AccountProfileArgument): Observable<typeof APAccountProfileUnion> {
    const { filter, returnFormatType } = dataservice;
    return this.fisAppQueryService.APAccountProfileGetData( filter, returnFormatType);
  }

  @Query(() => ARAccountProfileUnion, { name: 'ARAccountProfileQuery' })
  getARAccountProfileDataService(@Args() dataservice: AccountProfileArgument): Observable<typeof ARAccountProfileUnion> {
    const { filter, returnFormatType } = dataservice;
    return this.fisAppQueryService.ARAccountProfileGetData( filter, returnFormatType);
  }


  @Query(() => CMAccountProfileUnion, { name: 'CMAccountProfileQuery' })
  getCMAccountProfileDataService(@Args() dataservice: AccountProfileArgument): Observable<typeof CMAccountProfileUnion> {
    const { filter, returnFormatType } = dataservice;
    return this.fisAppQueryService.CMAccountProfileGetData( filter, returnFormatType);
  }


  @Query(() => DocumentUnion, { name: 'DocumentQuery' })
  getDocumentDataService(@Args() dataservice: DocumentArgument): Observable<typeof DocumentUnion> {
    const { filter, returnFormatType } = dataservice;
    return this.fisAppQueryService.DocumentGetData( filter, returnFormatType);
  }

  @Query(() => ARInvoiceDocumentUnion, { name: 'ARInvoiceDocumentQuery' })
  getARInvoiceDocumentDataService(@Args() dataservice: DocumentArgument): Observable<typeof ARInvoiceDocumentUnion> {
    const { filter, returnFormatType } = dataservice;
 
    return this.fisAppQueryService.ARInvoiceDocumentGetData( filter, returnFormatType);
  }

  @Query(() => APInvoiceDocumentUnion, { name: 'APInvoiceDocumentQuery' })
  getAPInvoiceDocumentDataService(@Args() dataservice: DocumentArgument): Observable<typeof APInvoiceDocumentUnion> {
    const { filter, returnFormatType } = dataservice;

    return this.fisAppQueryService.APInvoiceDocumentGetData( filter, returnFormatType);
  }
  @Query(() => APReceiptDocumentUnion, { name: 'APReceiptDocumentQuery' })
  getAPReceiptDocumentDataService(@Args() dataservice: DocumentArgument): Observable<typeof APReceiptDocumentUnion> {
    const { filter, returnFormatType } = dataservice;

    return this.fisAppQueryService.APReceiptDocumentGetData(filter, returnFormatType);
  }
  @Query(() => ARReceiptDocumentUnion, { name: 'ARReceiptDocumentQuery' })
  getARReceiptDocumentDataService(@Args() dataservice: DocumentArgument): Observable<typeof ARReceiptDocumentUnion> {
    const { filter, returnFormatType } = dataservice;
 
    return this.fisAppQueryService.ARReceiptDocumentGetData(filter, returnFormatType);
  }
  @Query(() => OrganisationProfileUnion, { name: 'OrganisationProfileQuery' })
  getOrganisationProfileDataService(@Args() dataservice: OrganisationProfileArgument): Observable<typeof OrganisationProfileUnion> {
    const { filter, returnFormatType } = dataservice;

    return this.fisAppQueryService.OrganisationProfileGetData(filter, returnFormatType);
  }

  @Query(() => ServiceProgramProfileUnion, { name: 'ServiceProgramProfileQuery' })
  getServiceProgramProfileDataService(@Args() dataservice: ServiceProgramProfileArgument): Observable<typeof ServiceProgramProfileUnion> {
    const { filter, returnFormatType } = dataservice;
    return this.fisAppQueryService.ServiceProgramProfileGetData(filter, returnFormatType);
  }

  @Query(() => FisServiceProgramUnion, { name: 'FisServiceProgramProfileQuery' })
  getFisServiceProgramProfileDataService(@Args() dataservice: FisServiceProgramProfileArgument): Observable<typeof FisServiceProgramUnion> {

    const { filter, returnFormatType } = dataservice;

    return this.fisAppQueryService.FisServiceProgramProfileGetData(filter, returnFormatType);
  }


  @Query(() => RoleTypeProfileUnion, { name: 'RoleTypeProfileQuery' })
  getRoleTypeProfileDataService(@Args() dataservice: RoleTypeProfileArgument): Observable<typeof RoleTypeProfileUnion> {

    const { filter, returnFormatType } = dataservice;

    return this.fisAppQueryService.RoleTypeProfileGetData(filter, returnFormatType);
  }

  @Query(() => ProductProfileUnion, { name: 'ProductProfileQuery' })
  getProductProfileDataService(@Args() dataservice: ProductProfileArgument): Observable<typeof ProductProfileUnion> {
    const { filter, returnFormatType } = dataservice;
    return this.fisAppQueryService.ProductProfileGetData(filter, returnFormatType);
  }

  @Query(() => LeaveBalanceUnion, { name: 'LeaveBalanceQuery' })
  getLeaveBalanceDataService(@Args() dataservice: LeaveBalanceArgument): Observable<typeof LeaveBalanceUnion> {
    const { filter, returnFormatType } = dataservice;
    return this.fisAppQueryService.LeaveBalanceGetData(filter, returnFormatType);
  }

  @Query(() => LeaveHistoryUnion, { name: 'LeaveHistoryQuery' })
  getLeaveHistoryDataService(@Args() dataservice: LeaveHistoryArgument): Observable<typeof LeaveHistoryUnion> {
    const { filter, returnFormatType } = dataservice;
    return this.fisAppQueryService.LeaveHistoryGetData(filter, returnFormatType);
  }

  @Query(() => LeaveTypeProfileUnion, { name: 'LeaveTypeProfileQuery' })
  getLeaveTypeProfileDataService(@Args() dataservice: LeaveTypeProfileArgument): Observable<typeof LeaveTypeProfileUnion> {
    const { filter, returnFormatType } = dataservice;
    return this.fisAppQueryService.LeaveTypeProfileGetData(filter, returnFormatType);
  }
}
