import {  Module } from '@nestjs/common';
import { GraphQLModule } from '@nestjs/graphql';
import { join } from 'path';
import { ConfigModule } from '@nestjs/config';

import { SitesModule } from './PlantationSiteOperationModule/sites/sites.module';

import { SubblockModule } from './PlantationSiteOperationModule/subblock/subblock.module';
import { PhaseModule } from './PlantationSiteOperationModule/phase/phase.module';
import { BlockModule } from './PlantationSiteOperationModule/block/block.module';
import { TransactionModule } from './PlantationSiteOperationModule/transaction/transaction.module';
import { HttpModule } from '@nestjs/axios';
import { DataserviceModule } from './FisAppQueryModule/dataservice.module';
import { CommonServiceChannelController } from './common-service-channel/common-service-channel.controller';
import { formatError } from './formatError';


@Module({
  imports: [
    ConfigModule.forRoot(),
    GraphQLModule.forRoot({
      autoSchemaFile: join(process.cwd(), 'src/schema.gql'),
      sortSchema: true,
      debug: true,
      playground: true,
      installSubscriptionHandlers: true,
      formatError: formatError
    }),
    SitesModule,
    SubblockModule,
    PhaseModule,
    BlockModule,
    TransactionModule,
    HttpModule,
    DataserviceModule
  ],
  providers: [],
  controllers: [CommonServiceChannelController]
})
export class AppModule { }
